@@ -34,7 +34,6 @@
 #include <libtracker-data/tracker-sparql-query.h>
 
 static gchar *tests_data_dir = NULL;
-static gchar *xdg_location = NULL;
 
 typedef struct _TestInfo TestInfo;
 
@@ -43,6 +42,7 @@ struct _TestInfo {
 	const gchar *data;
 	gboolean expect_query_error;
 	gboolean expect_update_error;
+	gchar *data_location;
 };
 
 const TestInfo tests[] = {
@@ -255,7 +255,9 @@ test_sparql_query (TestInfo      *test_info,
 	gchar *query, *query_filename;
 	gchar *results_filename;
 	gchar *prefix, *data_prefix, *test_prefix;
-	const gchar *test_schemas[2] = { NULL, NULL };
+	GFile *file, *test_schemas, *data_location;
+	TrackerDataManager *manager;
+	TrackerData *data_update;
 
 	/* initialization */
 	prefix = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", NULL);
@@ -263,24 +265,31 @@ test_sparql_query (TestInfo      *test_info,
 	test_prefix = g_build_filename (prefix, test_info->test_name, NULL);
 	g_free (prefix);
 
-	test_schemas[0] = data_prefix;
+	file = g_file_new_for_path (data_prefix);
+	test_schemas = g_file_get_parent (file);
+	g_object_unref (file);
+
+	data_location = g_file_new_for_path (test_info->data_location);
 
 	tracker_db_journal_set_rotating (FALSE, G_MAXSIZE, NULL);
 
-	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
-	                           test_schemas,
-	                           NULL, FALSE, FALSE,
-	                           100, 100, NULL, NULL, NULL, &error);
-
+	manager = tracker_data_manager_new (TRACKER_DB_MANAGER_FORCE_REINDEX,
+	                                    data_location, data_location, test_schemas, /* loc, domain and ontology_name */
+	                                    FALSE, FALSE, 100, 100);
+	g_initable_init (G_INITABLE (manager), NULL, &error);
 	g_assert_no_error (error);
 
+	data_update = tracker_data_manager_get_data (manager);
+
 	/* data_path = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", NULL); */
 
 	/* load data set */
 	data_filename = g_strconcat (data_prefix, ".ttl", NULL);
 	if (g_file_test (data_filename, G_FILE_TEST_IS_REGULAR)) {
-		tracker_turtle_reader_load (data_filename, &error);
+		GFile *file = g_file_new_for_path (data_filename);
+		tracker_turtle_reader_load (file, data_update, &error);
 		g_assert_no_error (error);
+		g_object_unref (file);
 	} else {
 		/* no .ttl available, assume .rq with SPARQL Update */
 		gchar *data;
@@ -291,7 +300,7 @@ test_sparql_query (TestInfo      *test_info,
 		g_file_get_contents (data_filename, &data, NULL, &error);
 		g_assert_no_error (error);
 
-		tracker_data_update_sparql (data, &error);
+		tracker_data_update_sparql (data_update, data, &error);
 		if (test_info->expect_update_error) {
 			g_assert (error != NULL);
 			g_clear_error (&error);
@@ -310,7 +319,7 @@ test_sparql_query (TestInfo      *test_info,
 
 	/* perform actual query */
 
-	cursor = tracker_data_query_sparql_cursor (query, &error);
+	cursor = tracker_data_query_sparql_cursor (manager, query, &error);
 
 	check_result (cursor, test_info, results_filename, error);
 
@@ -320,7 +329,7 @@ test_sparql_query (TestInfo      *test_info,
 	query_filename = g_strconcat (test_prefix, ".extra.rq", NULL);
 	if (g_file_get_contents (query_filename, &query, NULL, NULL)) {
 		g_object_unref (cursor);
-		cursor = tracker_data_query_sparql_cursor (query, &error);
+		cursor = tracker_data_query_sparql_cursor (manager, query, &error);
 		g_assert_no_error (error);
 		g_free (results_filename);
 		results_filename = g_strconcat (test_prefix, ".extra.out", NULL);
@@ -340,35 +349,24 @@ test_sparql_query (TestInfo      *test_info,
 	g_free (query_filename);
 	g_free (query);
 	g_free (results_filename);
-
-	tracker_data_manager_shutdown ();
+	g_object_unref (test_schemas);
+	g_object_unref (data_location);
+	g_object_unref (manager);
 }
 
 static void
 setup (TestInfo      *info,
        gconstpointer  context)
 {
-	gint i;
+	const TestInfo *test = context;
+	gchar *basename;
 
-	i = GPOINTER_TO_INT (context);
-	*info = tests[i];
+	*info = *test;
 
-	/* Sadly, we can't use ONE location per test because GLib
-	 * caches XDG env vars, so g_get_*dir() will not change if we
-	 * update the environment, this sucks majorly.
-	 */
-	if (!xdg_location) {
-		gchar *basename;
-
-		/* NOTE: g_test_build_filename() doesn't work env vars G_TEST_* are not defined?? */
-		basename = g_strdup_printf ("%d", g_test_rand_int_range (0, G_MAXINT));
-		xdg_location = g_build_path (G_DIR_SEPARATOR_S, tests_data_dir, basename, NULL);
-		g_free (basename);
-
-		g_assert_true (g_setenv ("XDG_DATA_HOME", xdg_location, TRUE));
-		g_assert_true (g_setenv ("XDG_CACHE_HOME", xdg_location, TRUE));
-		g_assert_true (g_setenv ("TRACKER_DB_ONTOLOGIES_DIR", TOP_SRCDIR "/src/ontologies/", TRUE));
-	}
+	/* NOTE: g_test_build_filename() doesn't work env vars G_TEST_* are not defined?? */
+	basename = g_strdup_printf ("%d", g_test_rand_int_range (0, G_MAXINT));
+	info->data_location = g_build_path (G_DIR_SEPARATOR_S, tests_data_dir, basename, NULL);
+	g_free (basename);
 }
 
 static void
@@ -378,14 +376,13 @@ teardown (TestInfo      *info,
 	gchar *cleanup_command;
 
 	/* clean up */
-	g_print ("Removing temporary data (%s)\n", xdg_location);
+	g_print ("Removing temporary data (%s)\n", info->data_location);
 
-	cleanup_command = g_strdup_printf ("rm -Rf %s/", xdg_location);
+	cleanup_command = g_strdup_printf ("rm -Rf %s/", info->data_location);
 	g_spawn_command_line_sync (cleanup_command, NULL, NULL, NULL, NULL);
 	g_free (cleanup_command);
 
-	g_free (xdg_location);
-	xdg_location = NULL;
+	g_free (info->data_location);
 }
 
 int
@@ -419,7 +416,7 @@ main (int argc, char **argv)
 #endif
 
 		testpath = g_strconcat ("/libtracker-data/sparql/", tests[i].test_name, NULL);
-		g_test_add (testpath, TestInfo, GINT_TO_POINTER(i), setup, test_sparql_query, teardown);
+		g_test_add (testpath, TestInfo, &tests[i], setup, test_sparql_query, teardown);
 		g_free (testpath);
 	}
 
